@@ -108,41 +108,83 @@ class OpenTravelData():
 
     >>> myOPTD.extractPORSubsetFromOPTD()
 
-    >>> myOPTD.getServingPORList ('IEV')
-    {'original': {'iata_code': 'IEV',
-     'location_type': None,
-     'geoname_id': None,
-     'envelope_id': None},
-    'tvl_list': [{'iata_code': 'IEV',
-     'location_type': 'A',
-     'geoname_id': 6300960,
-     'envelope_id': ''},
-    {'iata_code': 'KBP',
-     'location_type': 'A',
-     'geoname_id': 6300952,
-     'envelope_id': ''},
-    {'iata_code': 'QOF',
-     'location_type': 'B',
-     'geoname_id': 8260936,
-     'envelope_id': ''},
-    {'iata_code': 'QOH',
-     'location_type': 'B',
-     'geoname_id': 0,
-     'envelope_id': ''}]}
+    >>> import pprint as pp
 
-    >>> myOPTD.getServingPORList ('BAK')
-    {'original': {'iata_code': 'BAK',
-     'location_type': None,
-     'geoname_id': None,
-     'envelope_id': None},
-    'tvl_list': [{'iata_code': 'GYD',
-     'location_type': 'A',
-     'geoname_id': 6300924,
-     'envelope_id': ''},
-    {'iata_code': 'ZXT',
-     'location_type': 'A',
-     'geoname_id': 8521639,
-     'envelope_id': ''}]}
+    >>> pp.pprint (myOPTD.getServingPORList ('IEV'))
+    {'original': {'adm1_code': '12',
+              'adm1_name_utf': 'Kyiv City',
+              'country_code': 'UA',
+              'country_name': 'Ukraine',
+              'envelope_id': '',
+              'geoname_id': 703448,
+              'iata_code': 'IEV',
+              'location_type': 'C',
+              'name': 'Kyiv'},
+    'tvl_list': [{'adm1_code': '12',
+               'adm1_name_utf': 'Kyiv City',
+               'country_code': 'UA',
+               'country_name': 'Ukraine',
+               'envelope_id': '',
+               'geoname_id': 6300960,
+               'iata_code': 'IEV',
+               'location_type': 'A',
+               'name': 'Kyiv Zhuliany International Airport'},
+              {'adm1_code': '13',
+               'adm1_name_utf': 'Kyiv',
+               'country_code': 'UA',
+               'country_name': 'Ukraine',
+               'envelope_id': '',
+               'geoname_id': 6300952,
+               'iata_code': 'KBP',
+               'location_type': 'A',
+               'name': 'Kyiv Boryspil International Airport'},
+              {'adm1_code': '13',
+               'adm1_name_utf': 'Kyiv',
+               'country_code': 'UA',
+               'country_name': 'Ukraine',
+               'envelope_id': '',
+               'geoname_id': 8260936,
+               'iata_code': 'QOF',
+               'location_type': 'B',
+               'name': 'Darnytsia Bus Station'},
+              {'adm1_code': '',
+               'adm1_name_utf': '',
+               'country_code': 'UA',
+               'country_name': 'Ukraine',
+               'envelope_id': '',
+               'geoname_id': 0,
+               'iata_code': 'QOH',
+               'location_type': 'B',
+               'name': 'Kiev UA Hotel Rus'}]}
+    
+    >>> pp.pprint (myOPTD.getServingPORList ('BAK'))
+    {'original': {'adm1_code': '09',
+              'adm1_name_utf': 'Baki',
+              'country_code': 'AZ',
+              'country_name': 'Azerbaijan',
+              'envelope_id': '',
+              'geoname_id': 587084,
+              'iata_code': 'BAK',
+              'location_type': 'C',
+              'name': 'Baku'},
+    'tvl_list': [{'adm1_code': '09',
+               'adm1_name_utf': 'Baki',
+               'country_code': 'AZ',
+               'country_name': 'Azerbaijan',
+               'envelope_id': '',
+               'geoname_id': 6300924,
+               'iata_code': 'GYD',
+               'location_type': 'A',
+               'name': 'Heydar Aliyev International Airport'},
+              {'adm1_code': '09',
+               'adm1_name_utf': 'Baki',
+               'country_code': 'AZ',
+               'country_name': 'Azerbaijan',
+               'envelope_id': '',
+               'geoname_id': 8521639,
+               'iata_code': 'ZXT',
+               'location_type': 'A',
+               'name': 'Zabrat Airport'}]}
 
     """
     verbose = False
